==> dolphin-plugins_20.12.2.orig.tar.xz: dolphin-plugins-20.12.2/hg/bundledialog.h <==
/***************************************************************************
 *   Copyright (C) 2011 by Vishesh Yadav <vishesh3y@gmail.com>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#ifndef HGBUNDLEDIALOG_H
#define HGBUNDLEDIALOG_H

#include "dialogbase.h"

class QGroupBox;
class QCheckBox;
class QLineEdit;
class HgCommitInfoWidget;
class HgPathSelector;

/**
 * Dialog which implements bundle feature of Mercurial. Bundle enables
 * user to creates a file containing all the selected/desired changesets
 * in mercurial's internal format rather than patches. 
 * 
 * Changesets can either be selected by user or after being compared by
 * remote repository selected.
 *
 */
class HgBundleDialog : public DialogBase
{
    Q_OBJECT

public:
    explicit HgBundleDialog(QWidget *parent=0);

public Q_SLOTS:
    void done(int r) override;

private Q_SLOTS:
    void saveGeometry();

    /**
     * Opens a dialog listing all changeset from which user will select a 
     * changeset for base revision. 
     */
    void slotSelectChangeset();
    void slotAllChangesCheckToggled(int state);

private:
    void setupUI();

    /**
     * Creates bundle file.
     *
     * @param fileName Path to file where bundle will be created.
     */
    void createBundle(const QString &fileName);

    /**
     * Find all changesets in repository and show them in Commit Selector in 
     * Base Changeset selector.
     */
    void loadCommits();

private:
    QGroupBox *m_mainGroup;
    HgPathSelector *m_pathSelect;
    HgCommitInfoWidget *m_commitInfo;
    QPushButton *m_selectCommitButton;
    QLineEdit *m_baseRevision;
    QCheckBox *m_allChangesets;

    //options
    QGroupBox *m_optionGroup;
    QCheckBox *m_optForce;
    QCheckBox *m_optInsecure;
};

#endif /* HGBUNDLEDIALOG_H */

==> dolphin-plugins_21.12.3.orig.tar.xz: dolphin-plugins-21.12.3/hg/bundledialog.h <==
/*
    SPDX-FileCopyrightText: 2011 Vishesh Yadav <vishesh3y@gmail.com>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#ifndef HGBUNDLEDIALOG_H
#define HGBUNDLEDIALOG_H

#include "dialogbase.h"

class QGroupBox;
class QCheckBox;
class QLineEdit;
class HgCommitInfoWidget;
class HgPathSelector;

/**
 * Dialog which implements bundle feature of Mercurial. Bundle enables
 * user to creates a file containing all the selected/desired changesets
 * in mercurial's internal format rather than patches. 
 * 
 * Changesets can either be selected by user or after being compared by
 * remote repository selected.
 *
 */
class HgBundleDialog : public DialogBase
{
    Q_OBJECT

public:
    explicit HgBundleDialog(QWidget *parent=nullptr);

public Q_SLOTS:
    void done(int r) override;

private Q_SLOTS:
    void saveGeometry();

    /**
     * Opens a dialog listing all changeset from which user will select a 
     * changeset for base revision. 
     */
    void slotSelectChangeset();
    void slotAllChangesCheckToggled(int state);

private:
    void setupUI();

    /**
     * Creates bundle file.
     *
     * @param fileName Path to file where bundle will be created.
     */
    void createBundle(const QString &fileName);

    /**
     * Find all changesets in repository and show them in Commit Selector in 
     * Base Changeset selector.
     */
    void loadCommits();

private:
    QGroupBox *m_mainGroup;
    HgPathSelector *m_pathSelect;
    HgCommitInfoWidget *m_commitInfo;
    QPushButton *m_selectCommitButton;
    QLineEdit *m_baseRevision;
    QCheckBox *m_allChangesets;

    //options
    QGroupBox *m_optionGroup;
    QCheckBox *m_optForce;
    QCheckBox *m_optInsecure;
};

#endif /* HGBUNDLEDIALOG_H */
